<?php

namespace App\Models;

// use Illuminate\Contracts\Auth\MustVerifyEmail;
use Illuminate\Database\Eloquent\Factories\HasFactory;
use Illuminate\Foundation\Auth\User as Authenticatable;
use Illuminate\Notifications\Notifiable;
use Laravel\Sanctum\HasApiTokens;

class User extends Authenticatable
{
    use HasApiTokens, HasFactory, Notifiable;

    /**
     * The attributes that are mass assignable.
     *
     * @var array<int, string>
     */
    protected $fillable = [
        'name',
        'email',
        'password',
        'mobile',
        'location_id',
        'gender',
        'role',
        'otp',
        'occupation',
        'via',
        'is_deleted',
        'firebase_token',
        'user_img',
        'status',
        'email_verified_at'

    ];

    /**
     * The attributes that should be hidden for serialization.
     *
     * @var array<int, string>
     */
    protected $hidden = [
        'password',
        'remember_token',
    ];

    /**
     * The attributes that should be cast.
     *
     * @var array<string, string>
     */
    protected $casts = [
        'email_verified_at' => 'datetime',
        'password' => 'hashed',
    ];

    public function associate(){
        return $this->hasOne('App\Models\AssociateProfile', 'user_id');
    }

    public function getLocation(){
        return $this->belongsTo('App\Models\Location', 'location_id');
    }

    public function getWallet(){
        return $this->hasMany('App\Models\Wallet', 'user_id')->orderBy('created_at', 'Desc');

    }

    // Method to calculate the total wallet amount
    public function getTotalWalletAmount()
    {
        return $this->getWallet->sum('amount');
    }

    public function leadPurchased(){
        return $this->hasMany('App\Models\PurchaseLeadDetails', 'user_id');
    }

}
